"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlantRecord = void 0;
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class PlantRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length < 3 || obj.name.length > 40) {
            throw new errors_1.ValidationError('Name must be between 3 and 40 characters.');
        }
        if (!obj.wateringPeriod || obj.wateringPeriod <= 0) {
            throw new errors_1.ValidationError('Watering period must be greater than 0.');
        }
        if (!obj.fertilizationPeriod || obj.fertilizationPeriod <= 0) {
            throw new errors_1.ValidationError('Fertilization period must be greater than 0.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.lastWatering = obj.lastWatering;
        this.wateringPeriod = obj.wateringPeriod;
        this.lastFertilization = obj.lastFertilization;
        this.fertilizationPeriod = obj.fertilizationPeriod;
        this.lastDustRemoval = obj.lastDustRemoval;
        this.quarantine = obj.quarantine;
        this.image = obj.image ? obj.image : 'defaultImage.png';
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `plants`");
            return result.map(obj => new PlantRecord(obj));
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `plants` WHERE `id` =:id", {
                id,
            });
            return result.length === 0 ? null : new PlantRecord(result[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `plants` VALUES(:id, :name, :lastWatering, :wateringPeriod, :lastFertilization, :fertilizationPeriod, :lastDustRemoval, :quarantine, :image)", {
                id: this.id,
                name: this.name,
                lastWatering: this.lastWatering,
                wateringPeriod: this.wateringPeriod,
                lastFertilization: this.lastFertilization,
                fertilizationPeriod: this.fertilizationPeriod,
                lastDustRemoval: this.lastDustRemoval,
                quarantine: this.quarantine,
                image: this.image,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `plants` SET `name` = :name, `wateringPeriod` = :wateringPeriod, `fertilizationPeriod` = :fertilizationPeriod, `quarantine` = :quarantine, `image` = :image WHERE id = :id", {
                id: this.id,
                name: this.name,
                wateringPeriod: this.wateringPeriod,
                fertilizationPeriod: this.fertilizationPeriod,
                quarantine: this.quarantine,
                image: this.image,
            });
        });
    }
    water() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `plants` SET `lastWatering` = :lastWatering WHERE id = :id", {
                id: this.id,
                lastWatering: this.lastWatering,
            });
        });
    }
    fertilize() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `plants` SET `lastFertilization` = :lastFertilization WHERE id = :id", {
                id: this.id,
                lastFertilization: this.lastFertilization,
            });
        });
    }
    removeDust() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `plants` SET `lastDustRemoval` = :lastDustRemoval WHERE id = :id", {
                id: this.id,
                lastDustRemoval: this.lastDustRemoval,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `plants` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.PlantRecord = PlantRecord;
//# sourceMappingURL=plant.record.js.map