"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.storage = exports.plantsRouter = void 0;
const express_1 = require("express");
const multer_1 = __importDefault(require("multer"));
const path_1 = __importDefault(require("path"));
const fs = require('fs');
const { promisify } = require('util');
const plant_record_1 = require("../records/plant.record");
exports.plantsRouter = (0, express_1.Router)();
exports.storage = multer_1.default.diskStorage({
    destination: (request, file, callback) => {
        callback(null, 'plantImages/');
    },
    filename: (req, file, callback) => {
        callback(null, file.originalname);
    }
});
const upload = (0, multer_1.default)({ storage: exports.storage, preservePath: true });
const unlinkAsync = promisify(fs.unlink);
exports.plantsRouter
    .get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plantList = yield plant_record_1.PlantRecord.listAll();
    res.json({
        plantList,
    });
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const onePlant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    res.json(onePlant);
}))
    .get('/getImage/:image', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const imagePath = path_1.default.join('/home/jleszkon/domains/jleszko.networkmanager.pl/api/plant-control-backend/plantImages', `${req.params.image}`);
    if (imagePath) {
        res.sendFile(imagePath);
    }
    else {
        res.sendFile(path_1.default.join(__dirname, '../plantImages/defaultImage.png'));
    }
}))
    .post('/add/image', upload.single('file'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    res.json({ message: 'Successfully uploaded file' });
}))
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const newPlant = new plant_record_1.PlantRecord(req.body);
    yield newPlant.insert();
    res.json(newPlant);
}))
    .patch('/water/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    plant.lastWatering = req.body.lastWatering;
    yield plant.water();
    res.json(plant);
}))
    .patch('/fertilize/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    plant.lastFertilization = req.body.lastFertilization;
    yield plant.fertilize();
    res.json(plant);
}))
    .patch('/dust/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    plant.lastDustRemoval = req.body.lastDustRemoval;
    yield plant.removeDust();
    res.json(plant);
}))
    .patch('/edit/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    const updatePlant = req.body;
    const oldImage = plant.image;
    if (oldImage !== updatePlant.image)
        plant.image = updatePlant.image;
    plant.name = updatePlant.name;
    plant.wateringPeriod = updatePlant.wateringPeriod;
    plant.fertilizationPeriod = updatePlant.fertilizationPeriod;
    plant.quarantine = updatePlant.quarantine;
    if (oldImage !== updatePlant.image && oldImage !== 'defaultImage.png') {
        yield unlinkAsync(`plantImages/${oldImage}`);
    }
    yield plant.update();
    res.end();
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const plant = yield plant_record_1.PlantRecord.getOne(req.params.id);
    const file = plant.image;
    yield plant.delete();
    if (file !== 'defaultImage.png') {
        yield unlinkAsync(`plantImages/${file}`);
    }
    res.end("Deleting done.");
}));
//# sourceMappingURL=plants.js.map